@@ -1,4 +1,9 @@
 ## draw a set of Np particles from the user-specified distribution
+
+particles <- function (object, ...)
+  stop("function ",sQuote("particles")," is undefined for objects of class ",sQuote(class(object)))
+setGeneric('particles')  
+
 setMethod(
           "particles",
           "mif",
